// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: Globals.java
// Classes: Globals
// Original Author: jrobbins@ics.uci.edu
// $Id: Globals.java,v 1.7 1997/01/25 01:51:26 jrobbins Exp $

package uci.graphedit;

import java.applet.*;
import java.awt.*;
import java.net.*;

/** This class stores global info that is needed by all Editors. For
 * example, it aids in communication between the various Palette's and
 * Editor's by holding the next global Mode.  */

public class Globals {

  ////////////////////////////////////////////////////////////////
  // Applet related methods
  
  protected static AppletContext _appletContext;
  protected static Applet _applet;

  public static String defaultStatus = "";
  
  public static void setApplet(Applet a) {
    _applet = a;
    _appletContext = a.getAppletContext();
    clearStatus();
  }

  public static AppletContext getAppletContext() { return _appletContext; }
  public static Applet getApplet() { return _applet; }

  /** Show a string on the browser's status bar, or sprint a message
   * on the console. Needs-More-Work: should have a status bar on the
   * applet. */
  public static void showStatus(String s) {
    if (_appletContext != null) _appletContext.showStatus(s);
    else System.out.println(s);       
  }
  
  public static void clearStatus() {
    if (_appletContext != null) _appletContext.showStatus(defaultStatus);
  }

  public static void showDocument(URL url) {
    if (_appletContext != null) _appletContext.showDocument(url);
  }
  
  public static void showDocument(URL url, String target) {
    if (_appletContext != null) _appletContext.showDocument(url, target);
  }

  public static Image getImage(URL url) {
    if (_appletContext != null) return _appletContext.getImage(url);
    else return null;
  }

  public static void quit() {
    showStatus("Quiting");
    // Needs-More-Work: put up "are you sure?" dialog
    if (_appletContext != null) {
      // return are running an applet
      // Needs-More-Work: now it is up to the Applet to close all windows
      _applet.destroy();
    }
    // in any case, try to exit
    System.exit(0);
  }
    
  ////////////////////////////////////////////////////////////////
  // Methods for User Preferences
  
  /** The user's preferences for various editor features */
  protected static Prefs _prefs = new Prefs();

  /** reply the user's preferences */
  public static Prefs prefs() { return _prefs; }

  ////////////////////////////////////////////////////////////////
  // Methods for Editor Modes
  
  /** True if the next global Mode should remain as the next global
   * mode even after it has been given to one editor. */
  protected static boolean _sticky = false;

  /** Set whether the next global mode should remain as the next
   * global mode even after it has been given to one editor. */
  public static void setSticky(boolean b) { _sticky = b; }
  
  /** The next global mode. This is given to an editor on mouse entry */
  protected static Mode _mode;

  /** What mode should Editor's go into if the Palette is not
   * requesting a specific mode? */
  protected static Mode defaultMode() { return new ModeSelect(); }

  /** Set the next global mode */
  public static void mode(Mode m) { _mode = m; }

  /** Set the next global mode, and set it's stickiness */
  public static void mode(Mode m, boolean s) {
    _mode = m;
    _sticky = s;
  }

  /** Reply the next global mode. */
  public static Mode mode() {
    if (_mode == null) _mode = defaultMode();
    return _mode;
  }

  /** Determine the next global mode. This is called when a mode
   * finishes whatever it was meant to accomplish. For now, a sticky
   * mode stays the next global mode, all other modes are "popped" off
   * a single element stack and the defaultMode becomes the next
   * global mode. In the future it may be useful to have a true stack
   * of pending modes, I don't know.
   *
   * @see Mode#done */
  public static Mode nextMode() {
    if (!_sticky) _mode = defaultMode();
    return _mode;
  }

  ////////////////////////////////////////////////////////////////
  // Methods that keep track of the current editor
  
  /** The Editor that most recently contained the mouse */
  protected static Editor _curEditor;

  /** Setthe current Editor */
  public static void curEditor(Editor ce) { _curEditor = ce; }
  
  /** Reply the Editor that most recently contained the mouse */
  public static Editor curEditor() { return _curEditor; }

} /* end class Globals */
